@@ -416,6 +416,29 @@ class ETreeOnlyTestCase(HelperTestCase):
         self.assertRaises(
             LookupError, self.etree.XMLParser, encoding="hopefully unknown")
 
+    def test_elementtree_parser_target_type_error(self):
+        assertEquals = self.assertEquals
+        assertFalse  = self.assertFalse
+
+        events = []
+        class Target(object):
+            def start(self, tag, attrib):
+                events.append("start")
+                assertFalse(attrib)
+                assertEquals("TAG", tag)
+            def end(self, tag):
+                events.append("end")
+                assertEquals("TAG", tag)
+            def close(self):
+                return "DONE" # no Element!
+
+        parser = self.etree.XMLParser(target=Target())
+        tree = self.etree.ElementTree()
+
+        self.assertRaises(TypeError,
+                          tree.parse, StringIO("<TAG/>"), parser=parser)
+        self.assertEquals(["start", "end"], events)
+
     def test_iterwalk_tag(self):
         iterwalk = self.etree.iterwalk
         root = self.etree.XML('<a><b><d/></b><c/></a>')
@@ -533,6 +556,28 @@ class ETreeOnlyTestCase(HelperTestCase):
         root = tree.getroot()
         self.assertEquals(root.text, test_url)
 
+    def test_resolve_filename_dtd(self):
+        parse = self.etree.parse
+        parser = self.etree.XMLParser(attribute_defaults=True)
+        assertEqual = self.assertEqual
+        test_url = u"__nosuch.dtd"
+
+        class MyResolver(self.etree.Resolver):
+            def resolve(self, url, id, context):
+                assertEqual(url, test_url)
+                return self.resolve_filename(
+                    fileInTestDir('test.dtd'), context)
+
+        parser.resolvers.add(MyResolver())
+
+        xml = u'<!DOCTYPE a SYSTEM "%s"><a><b/></a>' % test_url
+        tree = parse(StringIO(xml), parser)
+        root = tree.getroot()
+        self.assertEquals(
+            root.attrib,    {'default': 'valueA'})
+        self.assertEquals(
+            root[0].attrib, {'default': 'valueB'})
+
     def test_resolve_empty(self):
         parse = self.etree.parse
         parser = self.etree.XMLParser(load_dtd=True)
@@ -1850,7 +1895,7 @@ class ETreeOnlyTestCase(HelperTestCase):
         xml = '<html><body></body></html>'
         tree = etree.parse(StringIO(xml))
         docinfo = tree.docinfo
-        self.assertEquals(docinfo.encoding,    None)
+        self.assertEquals(docinfo.encoding,    "UTF-8")
         self.assertEquals(docinfo.xml_version, "1.0")
         self.assertEquals(docinfo.public_id,   None)
         self.assertEquals(docinfo.system_url,  None)
